@@ -13,7 +13,7 @@ from functools import partial
 from . import view
 from . import server
 
-from PySide2 import QtCore, QtWidgets
+from PySide2 import QtCore
 
 from maya import cmds
 
@@ -38,6 +38,9 @@ class Controller(object):
         self.gui.ui.EndMonitorButton.clicked.connect(self.end_monitor)
         self.gui.ui.ManualReloadButton.clicked.connect(self.reload_manual)
 
+        self.gui.ui.ConsoleTextEdit.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
+        self.gui.ui.ConsoleTextEdit.customContextMenuRequested.connect(self.clear_console)
+
         self.__update_completer()
 
         self._filter = Filter(self.end_monitor, self.__update_completer)
@@ -47,7 +50,7 @@ class Controller(object):
         select_path = cmds.fileDialog2(dialogStyle=2, fileMode=3)[0]
         if not select_path:
             return
-            
+
         self.gui.ui.PathLineEdit.setText(select_path)
 
     def start_monitor(self):
@@ -91,6 +94,9 @@ class Controller(object):
             self.gui.ui.ReloadTargetBox.addItems(target_completer)
             self.gui.ui.ReloadTargetBox.setCurrentText(current_text)
 
+            self.gui.comp.setModel(QtCore.QStringListModel(target_completer))
+            self.gui.ui.ReloadTargetBox.setCompleter(self.gui.comp)
+
     def reload_manual(self):
         from . import app
 
@@ -100,6 +106,9 @@ class Controller(object):
 
         app.remove_include_module(target_module)
 
+    def clear_console(self):
+        self.gui.ui.ConsoleTextEdit.clear()
+
 
 class Filter(QtCore.QObject):
     def __init__(self, close_event, focus_event):
